# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'M2PlotPlus.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(418, 803)
        sizePolicy = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        icon = QIcon()
        icon.addFile(u":/ugao_icon.png", QSize(), QIcon.Normal, QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.actionECM = QAction(MainWindow)
        self.actionECM.setObjectName(u"actionECM")
        self.actionTest = QAction(MainWindow)
        self.actionTest.setObjectName(u"actionTest")
        self.actionShow = QAction(MainWindow)
        self.actionShow.setObjectName(u"actionShow")
        self.actionShow.setEnabled(False)
        self.actionECA = QAction(MainWindow)
        self.actionECA.setObjectName(u"actionECA")
        self.actionSlice = QAction(MainWindow)
        self.actionSlice.setObjectName(u"actionSlice")
        self.actionRectangle = QAction(MainWindow)
        self.actionRectangle.setObjectName(u"actionRectangle")
        self.actionCircle = QAction(MainWindow)
        self.actionCircle.setObjectName(u"actionCircle")
        self.actionConfirm_region = QAction(MainWindow)
        self.actionConfirm_region.setObjectName(u"actionConfirm_region")
        self.actionAuto_confirm = QAction(MainWindow)
        self.actionAuto_confirm.setObjectName(u"actionAuto_confirm")
        self.actionAuto_confirm.setCheckable(True)
        self.actionAuto_confirm.setChecked(True)
        self.actionECA_mdb = QAction(MainWindow)
        self.actionECA_mdb.setObjectName(u"actionECA_mdb")
        self.actionECM_mdb = QAction(MainWindow)
        self.actionECM_mdb.setObjectName(u"actionECM_mdb")
        self.actionOpen = QAction(MainWindow)
        self.actionOpen.setObjectName(u"actionOpen")
        self.actionOpen_data = QAction(MainWindow)
        self.actionOpen_data.setObjectName(u"actionOpen_data")
        self.actionAverage = QAction(MainWindow)
        self.actionAverage.setObjectName(u"actionAverage")
        self.actionAverage.setEnabled(False)
        self.actionY_axis_2D = QAction(MainWindow)
        self.actionY_axis_2D.setObjectName(u"actionY_axis_2D")
        self.actionY_axis_2D.setEnabled(False)
        self.actionX_axis_2D = QAction(MainWindow)
        self.actionX_axis_2D.setObjectName(u"actionX_axis_2D")
        self.actionX_axis_2D.setEnabled(False)
        self.actionPoint = QAction(MainWindow)
        self.actionPoint.setObjectName(u"actionPoint")
        self.actionExit = QAction(MainWindow)
        self.actionExit.setObjectName(u"actionExit")
        self.actionAbout = QAction(MainWindow)
        self.actionAbout.setObjectName(u"actionAbout")
        self.actionChangeLogLevel = QAction(MainWindow)
        self.actionChangeLogLevel.setObjectName(u"actionChangeLogLevel")
        self.actionSave_as_Text = QAction(MainWindow)
        self.actionSave_as_Text.setObjectName(u"actionSave_as_Text")
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.SumRangePanel = QGroupBox(self.centralwidget)
        self.SumRangePanel.setObjectName(u"SumRangePanel")
        self.SumRangePanel.setEnabled(True)
        self.SumRangePanel.setGeometry(QRect(30, 125, 381, 91))
        self.layoutWidget_1 = QWidget(self.SumRangePanel)
        self.layoutWidget_1.setObjectName(u"layoutWidget_1")
        self.layoutWidget_1.setGeometry(QRect(21, 56, 334, 29))
        self.horizontalLayout_2 = QHBoxLayout(self.layoutWidget_1)
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setSizeConstraint(QLayout.SetNoConstraint)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.label_5 = QLabel(self.layoutWidget_1)
        self.label_5.setObjectName(u"label_5")
        sizePolicy1 = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Preferred)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.label_5.sizePolicy().hasHeightForWidth())
        self.label_5.setSizePolicy(sizePolicy1)
        self.label_5.setMinimumSize(QSize(50, 0))

        self.horizontalLayout_2.addWidget(self.label_5)

        self.txtR0 = QLineEdit(self.layoutWidget_1)
        self.txtR0.setObjectName(u"txtR0")
        self.txtR0.setEnabled(False)

        self.horizontalLayout_2.addWidget(self.txtR0)

        self.label_4 = QLabel(self.layoutWidget_1)
        self.label_4.setObjectName(u"label_4")

        self.horizontalLayout_2.addWidget(self.label_4)

        self.txtR1 = QLineEdit(self.layoutWidget_1)
        self.txtR1.setObjectName(u"txtR1")
        self.txtR1.setEnabled(False)

        self.horizontalLayout_2.addWidget(self.txtR1)

        self.layoutWidget_2 = QWidget(self.SumRangePanel)
        self.layoutWidget_2.setObjectName(u"layoutWidget_2")
        self.layoutWidget_2.setGeometry(QRect(21, 21, 211, 29))
        self.horizontalLayout = QHBoxLayout(self.layoutWidget_2)
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalLayout.setSizeConstraint(QLayout.SetNoConstraint)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.label_6 = QLabel(self.layoutWidget_2)
        self.label_6.setObjectName(u"label_6")
        sizePolicy2 = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.label_6.sizePolicy().hasHeightForWidth())
        self.label_6.setSizePolicy(sizePolicy2)
        self.label_6.setMinimumSize(QSize(0, 0))

        self.horizontalLayout.addWidget(self.label_6)

        self.cbR = QComboBox(self.layoutWidget_2)
        self.cbR.setObjectName(u"cbR")
        self.cbR.setEnabled(False)
        sizePolicy3 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
        sizePolicy3.setHorizontalStretch(0)
        sizePolicy3.setVerticalStretch(0)
        sizePolicy3.setHeightForWidth(self.cbR.sizePolicy().hasHeightForWidth())
        self.cbR.setSizePolicy(sizePolicy3)
        self.cbR.setMinimumSize(QSize(160, 0))

        self.horizontalLayout.addWidget(self.cbR)

        self.layoutWidget_3 = QWidget(self.centralwidget)
        self.layoutWidget_3.setObjectName(u"layoutWidget_3")
        self.layoutWidget_3.setGeometry(QRect(10, 0, 401, 120))
        self.gridLayout = QGridLayout(self.layoutWidget_3)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setSizeConstraint(QLayout.SetMinimumSize)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.cbX = QComboBox(self.layoutWidget_3)
        self.cbX.setObjectName(u"cbX")
        self.cbX.setEnabled(False)
        sizePolicy4 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed)
        sizePolicy4.setHorizontalStretch(0)
        sizePolicy4.setVerticalStretch(0)
        sizePolicy4.setHeightForWidth(self.cbX.sizePolicy().hasHeightForWidth())
        self.cbX.setSizePolicy(sizePolicy4)

        self.gridLayout.addWidget(self.cbX, 1, 2, 1, 1)

        self.txt_label_x = QLineEdit(self.layoutWidget_3)
        self.txt_label_x.setObjectName(u"txt_label_x")
        self.txt_label_x.setEnabled(False)
        sizePolicy4.setHeightForWidth(self.txt_label_x.sizePolicy().hasHeightForWidth())
        self.txt_label_x.setSizePolicy(sizePolicy4)

        self.gridLayout.addWidget(self.txt_label_x, 1, 3, 1, 1)

        self.label_9 = QLabel(self.layoutWidget_3)
        self.label_9.setObjectName(u"label_9")

        self.gridLayout.addWidget(self.label_9, 0, 3, 1, 1)

        self.label = QLabel(self.layoutWidget_3)
        self.label.setObjectName(u"label")
        self.label.setEnabled(True)
        sizePolicy1.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy1)

        self.gridLayout.addWidget(self.label, 1, 0, 1, 1)

        self.cbY = QComboBox(self.layoutWidget_3)
        self.cbY.setObjectName(u"cbY")
        self.cbY.setEnabled(False)

        self.gridLayout.addWidget(self.cbY, 2, 2, 1, 1)

        self.label_2 = QLabel(self.layoutWidget_3)
        self.label_2.setObjectName(u"label_2")
        sizePolicy1.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy1)

        self.gridLayout.addWidget(self.label_2, 2, 0, 1, 1)

        self.label_3 = QLabel(self.layoutWidget_3)
        self.label_3.setObjectName(u"label_3")
        sizePolicy1.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy1)

        self.gridLayout.addWidget(self.label_3, 3, 0, 1, 1)

        self.horizontalSpacer = QSpacerItem(25, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout.addItem(self.horizontalSpacer, 1, 1, 1, 1)

        self.txt_label_y = QLineEdit(self.layoutWidget_3)
        self.txt_label_y.setObjectName(u"txt_label_y")
        self.txt_label_y.setEnabled(False)
        sizePolicy4.setHeightForWidth(self.txt_label_y.sizePolicy().hasHeightForWidth())
        self.txt_label_y.setSizePolicy(sizePolicy4)

        self.gridLayout.addWidget(self.txt_label_y, 2, 3, 1, 1)

        self.cbZ = QComboBox(self.layoutWidget_3)
        self.cbZ.setObjectName(u"cbZ")
        self.cbZ.setEnabled(False)

        self.gridLayout.addWidget(self.cbZ, 3, 2, 1, 1)

        self.label_8 = QLabel(self.layoutWidget_3)
        self.label_8.setObjectName(u"label_8")

        self.gridLayout.addWidget(self.label_8, 0, 2, 1, 1)

        self.txt_unit_x = QLineEdit(self.layoutWidget_3)
        self.txt_unit_x.setObjectName(u"txt_unit_x")
        self.txt_unit_x.setEnabled(False)
        sizePolicy4.setHeightForWidth(self.txt_unit_x.sizePolicy().hasHeightForWidth())
        self.txt_unit_x.setSizePolicy(sizePolicy4)

        self.gridLayout.addWidget(self.txt_unit_x, 1, 4, 1, 1)

        self.txt_unit_y = QLineEdit(self.layoutWidget_3)
        self.txt_unit_y.setObjectName(u"txt_unit_y")
        self.txt_unit_y.setEnabled(False)
        sizePolicy4.setHeightForWidth(self.txt_unit_y.sizePolicy().hasHeightForWidth())
        self.txt_unit_y.setSizePolicy(sizePolicy4)

        self.gridLayout.addWidget(self.txt_unit_y, 2, 4, 1, 1)

        self.label_10 = QLabel(self.layoutWidget_3)
        self.label_10.setObjectName(u"label_10")

        self.gridLayout.addWidget(self.label_10, 0, 4, 1, 1)

        self.showButton = QPushButton(self.centralwidget)
        self.showButton.setObjectName(u"showButton")
        self.showButton.setEnabled(False)
        self.showButton.setGeometry(QRect(280, 220, 77, 30))
        self.showButton.setAutoDefault(True)
        self.openButton = QPushButton(self.centralwidget)
        self.openButton.setObjectName(u"openButton")
        self.openButton.setGeometry(QRect(10, 220, 77, 30))
        self.openButton.setAutoDefault(True)
        self.openButton.setFlat(False)
        self.groupBox_int = QGroupBox(self.centralwidget)
        self.groupBox_int.setObjectName(u"groupBox_int")
        self.groupBox_int.setGeometry(QRect(20, 280, 391, 91))
        self.layoutWidget_4 = QWidget(self.groupBox_int)
        self.layoutWidget_4.setObjectName(u"layoutWidget_4")
        self.layoutWidget_4.setGeometry(QRect(10, 60, 371, 29))
        self.horizontalLayout_int_att = QHBoxLayout(self.layoutWidget_4)
        self.horizontalLayout_int_att.setSpacing(6)
        self.horizontalLayout_int_att.setObjectName(u"horizontalLayout_int_att")
        self.horizontalLayout_int_att.setContentsMargins(0, 0, 0, 0)
        self.chk_int_log = QCheckBox(self.layoutWidget_4)
        self.chk_int_log.setObjectName(u"chk_int_log")

        self.horizontalLayout_int_att.addWidget(self.chk_int_log)

        self.chk_smooth = QCheckBox(self.layoutWidget_4)
        self.chk_smooth.setObjectName(u"chk_smooth")

        self.horizontalLayout_int_att.addWidget(self.chk_smooth)

        self.label_smooth_win = QLabel(self.layoutWidget_4)
        self.label_smooth_win.setObjectName(u"label_smooth_win")
        self.label_smooth_win.setEnabled(False)

        self.horizontalLayout_int_att.addWidget(self.label_smooth_win)

        self.txt_smooth_win = QLineEdit(self.layoutWidget_4)
        self.txt_smooth_win.setObjectName(u"txt_smooth_win")
        self.txt_smooth_win.setEnabled(False)
        sizePolicy5 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
        sizePolicy5.setHorizontalStretch(0)
        sizePolicy5.setVerticalStretch(0)
        sizePolicy5.setHeightForWidth(self.txt_smooth_win.sizePolicy().hasHeightForWidth())
        self.txt_smooth_win.setSizePolicy(sizePolicy5)
        self.txt_smooth_win.setMinimumSize(QSize(30, 0))
        self.txt_smooth_win.setContextMenuPolicy(Qt.DefaultContextMenu)

        self.horizontalLayout_int_att.addWidget(self.txt_smooth_win)

        self.label_smooth_tim = QLabel(self.layoutWidget_4)
        self.label_smooth_tim.setObjectName(u"label_smooth_tim")
        self.label_smooth_tim.setEnabled(False)

        self.horizontalLayout_int_att.addWidget(self.label_smooth_tim)

        self.txt_smooth_tim = QLineEdit(self.layoutWidget_4)
        self.txt_smooth_tim.setObjectName(u"txt_smooth_tim")
        self.txt_smooth_tim.setEnabled(False)
        self.txt_smooth_tim.setMinimumSize(QSize(30, 0))

        self.horizontalLayout_int_att.addWidget(self.txt_smooth_tim)

        self.horizontalSpacer_6 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_int_att.addItem(self.horizontalSpacer_6)

        self.horizontalLayout_int_att.setStretch(3, 1)
        self.horizontalLayout_int_att.setStretch(5, 1)
        self.layoutWidget_5 = QWidget(self.groupBox_int)
        self.layoutWidget_5.setObjectName(u"layoutWidget_5")
        self.layoutWidget_5.setGeometry(QRect(10, 20, 371, 31))
        self.horizontalLayout_int = QHBoxLayout(self.layoutWidget_5)
        self.horizontalLayout_int.setObjectName(u"horizontalLayout_int")
        self.horizontalLayout_int.setSizeConstraint(QLayout.SetNoConstraint)
        self.horizontalLayout_int.setContentsMargins(0, 0, 0, 0)
        self.chk_int_auto_range = QCheckBox(self.layoutWidget_5)
        self.chk_int_auto_range.setObjectName(u"chk_int_auto_range")
        self.chk_int_auto_range.setChecked(True)

        self.horizontalLayout_int.addWidget(self.chk_int_auto_range)

        self.horizontalLayout_int_range = QHBoxLayout()
        self.horizontalLayout_int_range.setObjectName(u"horizontalLayout_int_range")
        self.label_int_range = QLabel(self.layoutWidget_5)
        self.label_int_range.setObjectName(u"label_int_range")
        self.label_int_range.setEnabled(False)

        self.horizontalLayout_int_range.addWidget(self.label_int_range)

        self.txt_int_min = QLineEdit(self.layoutWidget_5)
        self.txt_int_min.setObjectName(u"txt_int_min")
        self.txt_int_min.setEnabled(False)

        self.horizontalLayout_int_range.addWidget(self.txt_int_min)

        self.label_int_range_h = QLabel(self.layoutWidget_5)
        self.label_int_range_h.setObjectName(u"label_int_range_h")
        self.label_int_range_h.setEnabled(False)

        self.horizontalLayout_int_range.addWidget(self.label_int_range_h)

        self.txt_int_max = QLineEdit(self.layoutWidget_5)
        self.txt_int_max.setObjectName(u"txt_int_max")
        self.txt_int_max.setEnabled(False)

        self.horizontalLayout_int_range.addWidget(self.txt_int_max)


        self.horizontalLayout_int.addLayout(self.horizontalLayout_int_range)

        self.line = QFrame(self.centralwidget)
        self.line.setObjectName(u"line")
        self.line.setGeometry(QRect(10, 245, 401, 20))
        self.line.setFrameShape(QFrame.HLine)
        self.line.setFrameShadow(QFrame.Sunken)
        self.groupBox_xscale = QGroupBox(self.centralwidget)
        self.groupBox_xscale.setObjectName(u"groupBox_xscale")
        self.groupBox_xscale.setGeometry(QRect(20, 370, 391, 80))
        self.layoutWidget_6 = QWidget(self.groupBox_xscale)
        self.layoutWidget_6.setObjectName(u"layoutWidget_6")
        self.layoutWidget_6.setGeometry(QRect(10, 20, 371, 32))
        self.horizontalLayout_xslice = QHBoxLayout(self.layoutWidget_6)
        self.horizontalLayout_xslice.setObjectName(u"horizontalLayout_xslice")
        self.horizontalLayout_xslice.setSizeConstraint(QLayout.SetNoConstraint)
        self.horizontalLayout_xslice.setContentsMargins(0, 0, 0, 0)
        self.chk_xscale_auto_range = QCheckBox(self.layoutWidget_6)
        self.chk_xscale_auto_range.setObjectName(u"chk_xscale_auto_range")
        self.chk_xscale_auto_range.setChecked(True)

        self.horizontalLayout_xslice.addWidget(self.chk_xscale_auto_range)

        self.horizontalLayout_xscale_range = QHBoxLayout()
        self.horizontalLayout_xscale_range.setObjectName(u"horizontalLayout_xscale_range")
        self.label_xscale_range = QLabel(self.layoutWidget_6)
        self.label_xscale_range.setObjectName(u"label_xscale_range")
        self.label_xscale_range.setEnabled(False)

        self.horizontalLayout_xscale_range.addWidget(self.label_xscale_range)

        self.txt_xscale_min = QLineEdit(self.layoutWidget_6)
        self.txt_xscale_min.setObjectName(u"txt_xscale_min")
        self.txt_xscale_min.setEnabled(False)

        self.horizontalLayout_xscale_range.addWidget(self.txt_xscale_min)

        self.label_xscale_h = QLabel(self.layoutWidget_6)
        self.label_xscale_h.setObjectName(u"label_xscale_h")
        self.label_xscale_h.setEnabled(False)

        self.horizontalLayout_xscale_range.addWidget(self.label_xscale_h)

        self.txt_xscale_max = QLineEdit(self.layoutWidget_6)
        self.txt_xscale_max.setObjectName(u"txt_xscale_max")
        self.txt_xscale_max.setEnabled(False)

        self.horizontalLayout_xscale_range.addWidget(self.txt_xscale_max)


        self.horizontalLayout_xslice.addLayout(self.horizontalLayout_xscale_range)

        self.horizontalLayoutWidget = QWidget(self.groupBox_xscale)
        self.horizontalLayoutWidget.setObjectName(u"horizontalLayoutWidget")
        self.horizontalLayoutWidget.setGeometry(QRect(10, 50, 341, 27))
        self.horizontalLayout_3 = QHBoxLayout(self.horizontalLayoutWidget)
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.chk_xscale_log = QCheckBox(self.horizontalLayoutWidget)
        self.chk_xscale_log.setObjectName(u"chk_xscale_log")

        self.horizontalLayout_3.addWidget(self.chk_xscale_log)

        self.horizontalSpacer_2 = QSpacerItem(30, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_3.addItem(self.horizontalSpacer_2)

        self.chk_xscale_inv = QCheckBox(self.horizontalLayoutWidget)
        self.chk_xscale_inv.setObjectName(u"chk_xscale_inv")

        self.horizontalLayout_3.addWidget(self.chk_xscale_inv)

        self.groupBox_yscale = QGroupBox(self.centralwidget)
        self.groupBox_yscale.setObjectName(u"groupBox_yscale")
        self.groupBox_yscale.setGeometry(QRect(20, 450, 391, 80))
        self.layoutWidget_7 = QWidget(self.groupBox_yscale)
        self.layoutWidget_7.setObjectName(u"layoutWidget_7")
        self.layoutWidget_7.setGeometry(QRect(10, 20, 371, 32))
        self.horizontalLayout_yscale = QHBoxLayout(self.layoutWidget_7)
        self.horizontalLayout_yscale.setObjectName(u"horizontalLayout_yscale")
        self.horizontalLayout_yscale.setSizeConstraint(QLayout.SetNoConstraint)
        self.horizontalLayout_yscale.setContentsMargins(0, 0, 0, 0)
        self.chk_yscale_auto_range = QCheckBox(self.layoutWidget_7)
        self.chk_yscale_auto_range.setObjectName(u"chk_yscale_auto_range")
        self.chk_yscale_auto_range.setChecked(True)

        self.horizontalLayout_yscale.addWidget(self.chk_yscale_auto_range)

        self.horizontalLayout_yscale_range = QHBoxLayout()
        self.horizontalLayout_yscale_range.setObjectName(u"horizontalLayout_yscale_range")
        self.label_yscale_range = QLabel(self.layoutWidget_7)
        self.label_yscale_range.setObjectName(u"label_yscale_range")
        self.label_yscale_range.setEnabled(False)

        self.horizontalLayout_yscale_range.addWidget(self.label_yscale_range)

        self.txt_yscale_min = QLineEdit(self.layoutWidget_7)
        self.txt_yscale_min.setObjectName(u"txt_yscale_min")
        self.txt_yscale_min.setEnabled(False)

        self.horizontalLayout_yscale_range.addWidget(self.txt_yscale_min)

        self.label_yscale_h = QLabel(self.layoutWidget_7)
        self.label_yscale_h.setObjectName(u"label_yscale_h")
        self.label_yscale_h.setEnabled(False)

        self.horizontalLayout_yscale_range.addWidget(self.label_yscale_h)

        self.txt_yscale_max = QLineEdit(self.layoutWidget_7)
        self.txt_yscale_max.setObjectName(u"txt_yscale_max")
        self.txt_yscale_max.setEnabled(False)

        self.horizontalLayout_yscale_range.addWidget(self.txt_yscale_max)


        self.horizontalLayout_yscale.addLayout(self.horizontalLayout_yscale_range)

        self.horizontalLayoutWidget_2 = QWidget(self.groupBox_yscale)
        self.horizontalLayoutWidget_2.setObjectName(u"horizontalLayoutWidget_2")
        self.horizontalLayoutWidget_2.setGeometry(QRect(10, 50, 341, 27))
        self.horizontalLayout_4 = QHBoxLayout(self.horizontalLayoutWidget_2)
        self.horizontalLayout_4.setObjectName(u"horizontalLayout_4")
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.chk_yscale_log = QCheckBox(self.horizontalLayoutWidget_2)
        self.chk_yscale_log.setObjectName(u"chk_yscale_log")

        self.horizontalLayout_4.addWidget(self.chk_yscale_log)

        self.horizontalSpacer_3 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_4.addItem(self.horizontalSpacer_3)

        self.chk_yscale_inv = QCheckBox(self.horizontalLayoutWidget_2)
        self.chk_yscale_inv.setObjectName(u"chk_yscale_inv")

        self.horizontalLayout_4.addWidget(self.chk_yscale_inv)

        self.btIntApply = QPushButton(self.centralwidget)
        self.btIntApply.setObjectName(u"btIntApply")
        self.btIntApply.setGeometry(QRect(310, 260, 100, 30))
        self.btIntApply.setAutoDefault(True)
        self.groupBox_slice = QGroupBox(self.centralwidget)
        self.groupBox_slice.setObjectName(u"groupBox_slice")
        self.groupBox_slice.setGeometry(QRect(20, 530, 391, 221))
        self.tabWidget_Slice = QTabWidget(self.groupBox_slice)
        self.tabWidget_Slice.setObjectName(u"tabWidget_Slice")
        self.tabWidget_Slice.setEnabled(True)
        self.tabWidget_Slice.setGeometry(QRect(10, 20, 376, 191))
        self.tab_xzslice = QWidget()
        self.tab_xzslice.setObjectName(u"tab_xzslice")
        self.gridLayoutWidget = QWidget(self.tab_xzslice)
        self.gridLayoutWidget.setObjectName(u"gridLayoutWidget")
        self.gridLayoutWidget.setGeometry(QRect(10, 0, 351, 128))
        self.gridLayout_xscale = QGridLayout(self.gridLayoutWidget)
        self.gridLayout_xscale.setObjectName(u"gridLayout_xscale")
        self.gridLayout_xscale.setContentsMargins(0, 0, 0, 0)
        self.cb_xzslice_bin = QCheckBox(self.gridLayoutWidget)
        self.cb_xzslice_bin.setObjectName(u"cb_xzslice_bin")

        self.gridLayout_xscale.addWidget(self.cb_xzslice_bin, 3, 0, 1, 1)

        self.rd_xzslice_range = QRadioButton(self.gridLayoutWidget)
        self.rd_xzslice_range.setObjectName(u"rd_xzslice_range")

        self.gridLayout_xscale.addWidget(self.rd_xzslice_range, 2, 0, 1, 1)

        self.txt_xzslice_center = QLineEdit(self.gridLayoutWidget)
        self.txt_xzslice_center.setObjectName(u"txt_xzslice_center")

        self.gridLayout_xscale.addWidget(self.txt_xzslice_center, 0, 1, 1, 1)

        self.label_xzslice_h = QLabel(self.gridLayoutWidget)
        self.label_xzslice_h.setObjectName(u"label_xzslice_h")
        self.label_xzslice_h.setEnabled(False)
        self.label_xzslice_h.setAlignment(Qt.AlignCenter)

        self.gridLayout_xscale.addWidget(self.label_xzslice_h, 2, 2, 1, 1)

        self.rd_xzslice_value = QRadioButton(self.gridLayoutWidget)
        self.rd_xzslice_value.setObjectName(u"rd_xzslice_value")
        self.rd_xzslice_value.setChecked(True)

        self.gridLayout_xscale.addWidget(self.rd_xzslice_value, 0, 0, 1, 1)

        self.txt_xzslice_width = QLineEdit(self.gridLayoutWidget)
        self.txt_xzslice_width.setObjectName(u"txt_xzslice_width")

        self.gridLayout_xscale.addWidget(self.txt_xzslice_width, 0, 3, 1, 1)

        self.txt_xzslice_end = QLineEdit(self.gridLayoutWidget)
        self.txt_xzslice_end.setObjectName(u"txt_xzslice_end")
        self.txt_xzslice_end.setEnabled(False)

        self.gridLayout_xscale.addWidget(self.txt_xzslice_end, 2, 3, 1, 1)

        self.txt_xzslice_delta = QLineEdit(self.gridLayoutWidget)
        self.txt_xzslice_delta.setObjectName(u"txt_xzslice_delta")
        self.txt_xzslice_delta.setEnabled(False)

        self.gridLayout_xscale.addWidget(self.txt_xzslice_delta, 2, 5, 1, 1)

        self.txt_xzslice_start = QLineEdit(self.gridLayoutWidget)
        self.txt_xzslice_start.setObjectName(u"txt_xzslice_start")
        self.txt_xzslice_start.setEnabled(False)

        self.gridLayout_xscale.addWidget(self.txt_xzslice_start, 2, 1, 1, 1)

        self.label_xzslice_width = QLabel(self.gridLayoutWidget)
        self.label_xzslice_width.setObjectName(u"label_xzslice_width")
        self.label_xzslice_width.setAlignment(Qt.AlignCenter)

        self.gridLayout_xscale.addWidget(self.label_xzslice_width, 2, 4, 1, 1)

        self.txt_xzslice_bin = QLineEdit(self.gridLayoutWidget)
        self.txt_xzslice_bin.setObjectName(u"txt_xzslice_bin")
        self.txt_xzslice_bin.setEnabled(False)

        self.gridLayout_xscale.addWidget(self.txt_xzslice_bin, 3, 1, 1, 1)

        self.label_xzslice_pm = QLabel(self.gridLayoutWidget)
        self.label_xzslice_pm.setObjectName(u"label_xzslice_pm")
        self.label_xzslice_pm.setAlignment(Qt.AlignCenter)

        self.gridLayout_xscale.addWidget(self.label_xzslice_pm, 0, 2, 1, 1)

        self.txt_xzslice_center_to = QLineEdit(self.gridLayoutWidget)
        self.txt_xzslice_center_to.setObjectName(u"txt_xzslice_center_to")

        self.gridLayout_xscale.addWidget(self.txt_xzslice_center_to, 1, 3, 1, 1)

        self.txt_xzslice_center_step = QLineEdit(self.gridLayoutWidget)
        self.txt_xzslice_center_step.setObjectName(u"txt_xzslice_center_step")

        self.gridLayout_xscale.addWidget(self.txt_xzslice_center_step, 1, 5, 1, 1)

        self.label_11 = QLabel(self.gridLayoutWidget)
        self.label_11.setObjectName(u"label_11")

        self.gridLayout_xscale.addWidget(self.label_11, 1, 2, 1, 1)

        self.label_12 = QLabel(self.gridLayoutWidget)
        self.label_12.setObjectName(u"label_12")

        self.gridLayout_xscale.addWidget(self.label_12, 1, 4, 1, 1)

        self.btXZSlice1d = QPushButton(self.tab_xzslice)
        self.btXZSlice1d.setObjectName(u"btXZSlice1d")
        self.btXZSlice1d.setGeometry(QRect(80, 130, 77, 21))
        self.btXZSlice1d.setAutoDefault(True)
        self.btXZSlice2d = QPushButton(self.tab_xzslice)
        self.btXZSlice2d.setObjectName(u"btXZSlice2d")
        self.btXZSlice2d.setGeometry(QRect(260, 130, 77, 21))
        self.btXZSlice2d.setAutoDefault(True)
        self.btXZSlice1dclear = QPushButton(self.tab_xzslice)
        self.btXZSlice1dclear.setObjectName(u"btXZSlice1dclear")
        self.btXZSlice1dclear.setGeometry(QRect(160, 130, 61, 21))
        self.btXZSlice1dclear.setAutoDefault(True)
        self.tabWidget_Slice.addTab(self.tab_xzslice, "")
        self.tab_yzslice = QWidget()
        self.tab_yzslice.setObjectName(u"tab_yzslice")
        self.gridLayoutWidget_2 = QWidget(self.tab_yzslice)
        self.gridLayoutWidget_2.setObjectName(u"gridLayoutWidget_2")
        self.gridLayoutWidget_2.setGeometry(QRect(10, 0, 351, 128))
        self.gridLayout_yzslice = QGridLayout(self.gridLayoutWidget_2)
        self.gridLayout_yzslice.setObjectName(u"gridLayout_yzslice")
        self.gridLayout_yzslice.setContentsMargins(0, 0, 0, 0)
        self.txt_yzslice_center = QLineEdit(self.gridLayoutWidget_2)
        self.txt_yzslice_center.setObjectName(u"txt_yzslice_center")

        self.gridLayout_yzslice.addWidget(self.txt_yzslice_center, 0, 1, 1, 1)

        self.rd_yzslice_range = QRadioButton(self.gridLayoutWidget_2)
        self.rd_yzslice_range.setObjectName(u"rd_yzslice_range")

        self.gridLayout_yzslice.addWidget(self.rd_yzslice_range, 2, 0, 1, 1)

        self.rd_yzslice_value = QRadioButton(self.gridLayoutWidget_2)
        self.rd_yzslice_value.setObjectName(u"rd_yzslice_value")
        self.rd_yzslice_value.setChecked(True)

        self.gridLayout_yzslice.addWidget(self.rd_yzslice_value, 0, 0, 1, 1)

        self.txt_yzslice_end = QLineEdit(self.gridLayoutWidget_2)
        self.txt_yzslice_end.setObjectName(u"txt_yzslice_end")
        self.txt_yzslice_end.setEnabled(False)

        self.gridLayout_yzslice.addWidget(self.txt_yzslice_end, 2, 3, 1, 1)

        self.label_yzslice_h = QLabel(self.gridLayoutWidget_2)
        self.label_yzslice_h.setObjectName(u"label_yzslice_h")
        self.label_yzslice_h.setEnabled(False)
        self.label_yzslice_h.setAlignment(Qt.AlignCenter)

        self.gridLayout_yzslice.addWidget(self.label_yzslice_h, 2, 2, 1, 1)

        self.txt_yzslice_width = QLineEdit(self.gridLayoutWidget_2)
        self.txt_yzslice_width.setObjectName(u"txt_yzslice_width")

        self.gridLayout_yzslice.addWidget(self.txt_yzslice_width, 0, 3, 1, 1)

        self.txt_yzslice_start = QLineEdit(self.gridLayoutWidget_2)
        self.txt_yzslice_start.setObjectName(u"txt_yzslice_start")
        self.txt_yzslice_start.setEnabled(False)

        self.gridLayout_yzslice.addWidget(self.txt_yzslice_start, 2, 1, 1, 1)

        self.txt_yzslice_bin = QLineEdit(self.gridLayoutWidget_2)
        self.txt_yzslice_bin.setObjectName(u"txt_yzslice_bin")
        self.txt_yzslice_bin.setEnabled(False)

        self.gridLayout_yzslice.addWidget(self.txt_yzslice_bin, 3, 1, 1, 1)

        self.label_xzslice_width_2 = QLabel(self.gridLayoutWidget_2)
        self.label_xzslice_width_2.setObjectName(u"label_xzslice_width_2")
        self.label_xzslice_width_2.setAlignment(Qt.AlignCenter)

        self.gridLayout_yzslice.addWidget(self.label_xzslice_width_2, 2, 4, 1, 1)

        self.txt_yzslice_delta = QLineEdit(self.gridLayoutWidget_2)
        self.txt_yzslice_delta.setObjectName(u"txt_yzslice_delta")
        self.txt_yzslice_delta.setEnabled(False)

        self.gridLayout_yzslice.addWidget(self.txt_yzslice_delta, 2, 5, 1, 1)

        self.cb_yzslice_bin = QCheckBox(self.gridLayoutWidget_2)
        self.cb_yzslice_bin.setObjectName(u"cb_yzslice_bin")

        self.gridLayout_yzslice.addWidget(self.cb_yzslice_bin, 3, 0, 1, 1)

        self.label_yzslice_pm = QLabel(self.gridLayoutWidget_2)
        self.label_yzslice_pm.setObjectName(u"label_yzslice_pm")
        self.label_yzslice_pm.setAlignment(Qt.AlignCenter)

        self.gridLayout_yzslice.addWidget(self.label_yzslice_pm, 0, 2, 1, 1)

        self.label_13 = QLabel(self.gridLayoutWidget_2)
        self.label_13.setObjectName(u"label_13")

        self.gridLayout_yzslice.addWidget(self.label_13, 1, 2, 1, 1)

        self.txt_yzslice_center_to = QLineEdit(self.gridLayoutWidget_2)
        self.txt_yzslice_center_to.setObjectName(u"txt_yzslice_center_to")

        self.gridLayout_yzslice.addWidget(self.txt_yzslice_center_to, 1, 3, 1, 1)

        self.label_14 = QLabel(self.gridLayoutWidget_2)
        self.label_14.setObjectName(u"label_14")

        self.gridLayout_yzslice.addWidget(self.label_14, 1, 4, 1, 1)

        self.txt_yzslice_center_step = QLineEdit(self.gridLayoutWidget_2)
        self.txt_yzslice_center_step.setObjectName(u"txt_yzslice_center_step")

        self.gridLayout_yzslice.addWidget(self.txt_yzslice_center_step, 1, 5, 1, 1)

        self.btYZSlice1d = QPushButton(self.tab_yzslice)
        self.btYZSlice1d.setObjectName(u"btYZSlice1d")
        self.btYZSlice1d.setGeometry(QRect(80, 130, 77, 21))
        self.btYZSlice1d.setAutoDefault(True)
        self.btYZSlice2d = QPushButton(self.tab_yzslice)
        self.btYZSlice2d.setObjectName(u"btYZSlice2d")
        self.btYZSlice2d.setGeometry(QRect(260, 130, 77, 21))
        self.btYZSlice2d.setAutoDefault(True)
        self.btYZSlice1dclear = QPushButton(self.tab_yzslice)
        self.btYZSlice1dclear.setObjectName(u"btYZSlice1dclear")
        self.btYZSlice1dclear.setGeometry(QRect(160, 130, 61, 21))
        self.btYZSlice1dclear.setAutoDefault(True)
        self.tabWidget_Slice.addTab(self.tab_yzslice, "")
        self.tab_diagonal = QWidget()
        self.tab_diagonal.setObjectName(u"tab_diagonal")
        self.gridLayoutWidget_3 = QWidget(self.tab_diagonal)
        self.gridLayoutWidget_3.setObjectName(u"gridLayoutWidget_3")
        self.gridLayoutWidget_3.setGeometry(QRect(0, 0, 171, 71))
        self.gridLayout_yzslice_3 = QGridLayout(self.gridLayoutWidget_3)
        self.gridLayout_yzslice_3.setObjectName(u"gridLayout_yzslice_3")
        self.gridLayout_yzslice_3.setContentsMargins(0, 0, 0, 0)
        self.label_diagonal_sp = QLabel(self.gridLayoutWidget_3)
        self.label_diagonal_sp.setObjectName(u"label_diagonal_sp")
        self.label_diagonal_sp.setAlignment(Qt.AlignRight|Qt.AlignTrailing|Qt.AlignVCenter)

        self.gridLayout_yzslice_3.addWidget(self.label_diagonal_sp, 0, 0, 1, 1)

        self.label_diagonal_ep = QLabel(self.gridLayoutWidget_3)
        self.label_diagonal_ep.setObjectName(u"label_diagonal_ep")
        self.label_diagonal_ep.setAlignment(Qt.AlignRight|Qt.AlignTrailing|Qt.AlignVCenter)

        self.gridLayout_yzslice_3.addWidget(self.label_diagonal_ep, 1, 0, 1, 1)

        self.txt_diagonal_ep_y = QLineEdit(self.gridLayoutWidget_3)
        self.txt_diagonal_ep_y.setObjectName(u"txt_diagonal_ep_y")
        self.txt_diagonal_ep_y.setEnabled(True)

        self.gridLayout_yzslice_3.addWidget(self.txt_diagonal_ep_y, 1, 2, 1, 1)

        self.txt_diagonal_sp_x = QLineEdit(self.gridLayoutWidget_3)
        self.txt_diagonal_sp_x.setObjectName(u"txt_diagonal_sp_x")

        self.gridLayout_yzslice_3.addWidget(self.txt_diagonal_sp_x, 0, 1, 1, 1)

        self.txt_diagonal_ep_x = QLineEdit(self.gridLayoutWidget_3)
        self.txt_diagonal_ep_x.setObjectName(u"txt_diagonal_ep_x")
        self.txt_diagonal_ep_x.setEnabled(True)

        self.gridLayout_yzslice_3.addWidget(self.txt_diagonal_ep_x, 1, 1, 1, 1)

        self.txt_diagonal_sp_y = QLineEdit(self.gridLayoutWidget_3)
        self.txt_diagonal_sp_y.setObjectName(u"txt_diagonal_sp_y")

        self.gridLayout_yzslice_3.addWidget(self.txt_diagonal_sp_y, 0, 2, 1, 1)

        self.btDiagonal1d = QPushButton(self.tab_diagonal)
        self.btDiagonal1d.setObjectName(u"btDiagonal1d")
        self.btDiagonal1d.setGeometry(QRect(310, 10, 61, 21))
        self.btDiagonal1d.setAutoDefault(True)
        self.btDiagonal2d = QPushButton(self.tab_diagonal)
        self.btDiagonal2d.setObjectName(u"btDiagonal2d")
        self.btDiagonal2d.setEnabled(False)
        self.btDiagonal2d.setGeometry(QRect(310, 40, 61, 21))
        self.btDiagonal2d.setAutoDefault(True)
        self.gridLayoutWidget_4 = QWidget(self.tab_diagonal)
        self.gridLayoutWidget_4.setObjectName(u"gridLayoutWidget_4")
        self.gridLayoutWidget_4.setGeometry(QRect(180, 0, 122, 71))
        self.gridLayout_yzslice_4 = QGridLayout(self.gridLayoutWidget_4)
        self.gridLayout_yzslice_4.setObjectName(u"gridLayout_yzslice_4")
        self.gridLayout_yzslice_4.setContentsMargins(0, 0, 0, 0)
        self.label_diagonal_width = QLabel(self.gridLayoutWidget_4)
        self.label_diagonal_width.setObjectName(u"label_diagonal_width")
        self.label_diagonal_width.setAlignment(Qt.AlignRight|Qt.AlignTrailing|Qt.AlignVCenter)

        self.gridLayout_yzslice_4.addWidget(self.label_diagonal_width, 0, 0, 1, 1)

        self.txt_diagonal_binning = QLineEdit(self.gridLayoutWidget_4)
        self.txt_diagonal_binning.setObjectName(u"txt_diagonal_binning")
        self.txt_diagonal_binning.setEnabled(True)

        self.gridLayout_yzslice_4.addWidget(self.txt_diagonal_binning, 1, 1, 1, 1)

        self.label_diagonal_binning = QLabel(self.gridLayoutWidget_4)
        self.label_diagonal_binning.setObjectName(u"label_diagonal_binning")
        self.label_diagonal_binning.setAlignment(Qt.AlignRight|Qt.AlignTrailing|Qt.AlignVCenter)

        self.gridLayout_yzslice_4.addWidget(self.label_diagonal_binning, 1, 0, 1, 1)

        self.txt_diagonal_width = QLineEdit(self.gridLayoutWidget_4)
        self.txt_diagonal_width.setObjectName(u"txt_diagonal_width")

        self.gridLayout_yzslice_4.addWidget(self.txt_diagonal_width, 0, 1, 1, 1)

        self.tabWidget_Slice.addTab(self.tab_diagonal, "")
        self.tab = QWidget()
        self.tab.setObjectName(u"tab")
        self.layoutWidget_8 = QWidget(self.tab)
        self.layoutWidget_8.setObjectName(u"layoutWidget_8")
        self.layoutWidget_8.setGeometry(QRect(0, 10, 361, 27))
        self.layout_sliceMethod = QHBoxLayout(self.layoutWidget_8)
        self.layout_sliceMethod.setObjectName(u"layout_sliceMethod")
        self.layout_sliceMethod.setContentsMargins(0, 0, 0, 0)
        self.label_7 = QLabel(self.layoutWidget_8)
        self.label_7.setObjectName(u"label_7")
        self.label_7.setAlignment(Qt.AlignCenter)

        self.layout_sliceMethod.addWidget(self.label_7)

        self.rb_isAveSlice = QRadioButton(self.layoutWidget_8)
        self.rb_isAveSlice.setObjectName(u"rb_isAveSlice")
        self.rb_isAveSlice.setChecked(True)

        self.layout_sliceMethod.addWidget(self.rb_isAveSlice)

        self.rb_isSumSlice = QRadioButton(self.layoutWidget_8)
        self.rb_isSumSlice.setObjectName(u"rb_isSumSlice")

        self.layout_sliceMethod.addWidget(self.rb_isSumSlice)

        self.tabWidget_Slice.addTab(self.tab, "")
        self.btFindPlotter = QPushButton(self.centralwidget)
        self.btFindPlotter.setObjectName(u"btFindPlotter")
        self.btFindPlotter.setGeometry(QRect(370, 220, 30, 30))
        self.btFindPlotter.setIconSize(QSize(32, 32))
        self.btFindPlotter.setAutoDefault(True)
        self.cb_DetMapMode = QCheckBox(self.centralwidget)
        self.cb_DetMapMode.setObjectName(u"cb_DetMapMode")
        self.cb_DetMapMode.setGeometry(QRect(170, 220, 101, 25))
        MainWindow.setCentralWidget(self.centralwidget)
        self.layoutWidget_3.raise_()
        self.SumRangePanel.raise_()
        self.showButton.raise_()
        self.openButton.raise_()
        self.groupBox_int.raise_()
        self.line.raise_()
        self.groupBox_xscale.raise_()
        self.groupBox_yscale.raise_()
        self.btIntApply.raise_()
        self.groupBox_slice.raise_()
        self.btFindPlotter.raise_()
        self.cb_DetMapMode.raise_()
        self.menubar = QMenuBar(MainWindow)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 418, 24))
        self.menuFile = QMenu(self.menubar)
        self.menuFile.setObjectName(u"menuFile")
        self.menuEdit = QMenu(self.menubar)
        self.menuEdit.setObjectName(u"menuEdit")
        self.menuRegion_type = QMenu(self.menuEdit)
        self.menuRegion_type.setObjectName(u"menuRegion_type")
        self.menuFunction = QMenu(self.menubar)
        self.menuFunction.setObjectName(u"menuFunction")
        self.menuHelp = QMenu(self.menubar)
        self.menuHelp.setObjectName(u"menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        self.statusbar.setStyleSheet(u"background-color: rgb(255, 255, 255);")
        self.statusbar.setSizeGripEnabled(False)
        MainWindow.setStatusBar(self.statusbar)
        QWidget.setTabOrder(self.openButton, self.cbX)
        QWidget.setTabOrder(self.cbX, self.txt_label_x)
        QWidget.setTabOrder(self.txt_label_x, self.txt_unit_x)
        QWidget.setTabOrder(self.txt_unit_x, self.cbY)
        QWidget.setTabOrder(self.cbY, self.txt_label_y)
        QWidget.setTabOrder(self.txt_label_y, self.txt_unit_y)
        QWidget.setTabOrder(self.txt_unit_y, self.cbZ)
        QWidget.setTabOrder(self.cbZ, self.cbR)
        QWidget.setTabOrder(self.cbR, self.txtR0)
        QWidget.setTabOrder(self.txtR0, self.txtR1)
        QWidget.setTabOrder(self.txtR1, self.showButton)
        QWidget.setTabOrder(self.showButton, self.btFindPlotter)
        QWidget.setTabOrder(self.btFindPlotter, self.chk_int_auto_range)
        QWidget.setTabOrder(self.chk_int_auto_range, self.txt_int_min)
        QWidget.setTabOrder(self.txt_int_min, self.txt_int_max)
        QWidget.setTabOrder(self.txt_int_max, self.chk_int_log)
        QWidget.setTabOrder(self.chk_int_log, self.chk_smooth)
        QWidget.setTabOrder(self.chk_smooth, self.txt_smooth_win)
        QWidget.setTabOrder(self.txt_smooth_win, self.txt_smooth_tim)
        QWidget.setTabOrder(self.txt_smooth_tim, self.chk_xscale_auto_range)
        QWidget.setTabOrder(self.chk_xscale_auto_range, self.txt_xscale_min)
        QWidget.setTabOrder(self.txt_xscale_min, self.txt_xscale_max)
        QWidget.setTabOrder(self.txt_xscale_max, self.chk_xscale_log)
        QWidget.setTabOrder(self.chk_xscale_log, self.chk_xscale_inv)
        QWidget.setTabOrder(self.chk_xscale_inv, self.chk_yscale_auto_range)
        QWidget.setTabOrder(self.chk_yscale_auto_range, self.txt_yscale_min)
        QWidget.setTabOrder(self.txt_yscale_min, self.txt_yscale_max)
        QWidget.setTabOrder(self.txt_yscale_max, self.chk_yscale_log)
        QWidget.setTabOrder(self.chk_yscale_log, self.chk_yscale_inv)
        QWidget.setTabOrder(self.chk_yscale_inv, self.btIntApply)
        QWidget.setTabOrder(self.btIntApply, self.tabWidget_Slice)
        QWidget.setTabOrder(self.tabWidget_Slice, self.rd_xzslice_value)
        QWidget.setTabOrder(self.rd_xzslice_value, self.txt_xzslice_center)
        QWidget.setTabOrder(self.txt_xzslice_center, self.txt_xzslice_width)
        QWidget.setTabOrder(self.txt_xzslice_width, self.txt_xzslice_center_to)
        QWidget.setTabOrder(self.txt_xzslice_center_to, self.txt_xzslice_center_step)
        QWidget.setTabOrder(self.txt_xzslice_center_step, self.rd_xzslice_range)
        QWidget.setTabOrder(self.rd_xzslice_range, self.txt_xzslice_start)
        QWidget.setTabOrder(self.txt_xzslice_start, self.txt_xzslice_end)
        QWidget.setTabOrder(self.txt_xzslice_end, self.txt_xzslice_delta)
        QWidget.setTabOrder(self.txt_xzslice_delta, self.cb_xzslice_bin)
        QWidget.setTabOrder(self.cb_xzslice_bin, self.txt_xzslice_bin)
        QWidget.setTabOrder(self.txt_xzslice_bin, self.btXZSlice1d)
        QWidget.setTabOrder(self.btXZSlice1d, self.btXZSlice1dclear)
        QWidget.setTabOrder(self.btXZSlice1dclear, self.btXZSlice2d)
        QWidget.setTabOrder(self.btXZSlice2d, self.rd_yzslice_value)
        QWidget.setTabOrder(self.rd_yzslice_value, self.txt_yzslice_center)
        QWidget.setTabOrder(self.txt_yzslice_center, self.txt_yzslice_width)
        QWidget.setTabOrder(self.txt_yzslice_width, self.txt_yzslice_center_to)
        QWidget.setTabOrder(self.txt_yzslice_center_to, self.txt_yzslice_center_step)
        QWidget.setTabOrder(self.txt_yzslice_center_step, self.rd_yzslice_range)
        QWidget.setTabOrder(self.rd_yzslice_range, self.txt_yzslice_start)
        QWidget.setTabOrder(self.txt_yzslice_start, self.txt_yzslice_end)
        QWidget.setTabOrder(self.txt_yzslice_end, self.txt_yzslice_delta)
        QWidget.setTabOrder(self.txt_yzslice_delta, self.cb_yzslice_bin)
        QWidget.setTabOrder(self.cb_yzslice_bin, self.txt_yzslice_bin)
        QWidget.setTabOrder(self.txt_yzslice_bin, self.btYZSlice1d)
        QWidget.setTabOrder(self.btYZSlice1d, self.btYZSlice1dclear)
        QWidget.setTabOrder(self.btYZSlice1dclear, self.btYZSlice2d)
        QWidget.setTabOrder(self.btYZSlice2d, self.txt_diagonal_sp_x)
        QWidget.setTabOrder(self.txt_diagonal_sp_x, self.txt_diagonal_sp_y)
        QWidget.setTabOrder(self.txt_diagonal_sp_y, self.txt_diagonal_width)
        QWidget.setTabOrder(self.txt_diagonal_width, self.btDiagonal1d)
        QWidget.setTabOrder(self.btDiagonal1d, self.txt_diagonal_ep_x)
        QWidget.setTabOrder(self.txt_diagonal_ep_x, self.txt_diagonal_ep_y)
        QWidget.setTabOrder(self.txt_diagonal_ep_y, self.txt_diagonal_binning)
        QWidget.setTabOrder(self.txt_diagonal_binning, self.btDiagonal2d)
        QWidget.setTabOrder(self.btDiagonal2d, self.rb_isAveSlice)
        QWidget.setTabOrder(self.rb_isAveSlice, self.rb_isSumSlice)

        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuFunction.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.menuFile.addAction(self.actionOpen_data)
        self.menuFile.addAction(self.actionSave_as_Text)
        self.menuFile.addAction(self.actionExit)
        self.menuEdit.addAction(self.actionConfirm_region)
        self.menuEdit.addAction(self.menuRegion_type.menuAction())
        self.menuEdit.addAction(self.actionAuto_confirm)
        self.menuRegion_type.addAction(self.actionRectangle)
        self.menuRegion_type.addAction(self.actionCircle)
        self.menuRegion_type.addAction(self.actionPoint)
        self.menuFunction.addAction(self.actionShow)
        self.menuFunction.addAction(self.actionTest)
        self.menuHelp.addAction(self.actionChangeLogLevel)
        self.menuHelp.addAction(self.actionAbout)

        self.retranslateUi(MainWindow)
        self.rd_xzslice_range.toggled.connect(self.txt_xzslice_center.setDisabled)
        self.rd_xzslice_range.toggled.connect(self.txt_xzslice_width.setDisabled)
        self.rd_xzslice_range.toggled.connect(self.txt_xzslice_start.setEnabled)
        self.rd_xzslice_range.toggled.connect(self.txt_xzslice_end.setEnabled)
        self.rd_xzslice_value.toggled.connect(self.txt_xzslice_center.setEnabled)
        self.rd_xzslice_value.toggled.connect(self.txt_xzslice_width.setEnabled)
        self.rd_xzslice_value.toggled.connect(self.txt_xzslice_start.setDisabled)
        self.rd_xzslice_value.toggled.connect(self.txt_xzslice_end.setDisabled)
        self.rd_yzslice_value.toggled.connect(self.txt_yzslice_center.setEnabled)
        self.rd_yzslice_value.toggled.connect(self.txt_yzslice_width.setEnabled)
        self.rd_yzslice_value.toggled.connect(self.txt_yzslice_start.setDisabled)
        self.rd_yzslice_value.toggled.connect(self.txt_yzslice_end.setDisabled)
        self.rd_yzslice_range.toggled.connect(self.txt_yzslice_start.setEnabled)
        self.rd_yzslice_range.toggled.connect(self.txt_yzslice_end.setEnabled)
        self.rd_yzslice_range.toggled.connect(self.txt_yzslice_center.setDisabled)
        self.rd_yzslice_range.toggled.connect(self.txt_yzslice_width.setDisabled)
        self.chk_smooth.toggled.connect(self.label_smooth_win.setEnabled)
        self.chk_smooth.toggled.connect(self.label_smooth_tim.setEnabled)
        self.chk_smooth.toggled.connect(self.txt_smooth_win.setEnabled)
        self.chk_smooth.toggled.connect(self.txt_smooth_tim.setEnabled)
        self.rd_xzslice_range.toggled.connect(self.txt_xzslice_delta.setEnabled)
        self.rd_xzslice_value.toggled.connect(self.txt_xzslice_delta.setDisabled)
        self.rd_yzslice_value.toggled.connect(self.txt_yzslice_delta.setDisabled)
        self.rd_yzslice_range.toggled.connect(self.txt_yzslice_delta.setEnabled)
        self.rd_xzslice_value.toggled.connect(self.txt_xzslice_center_to.setEnabled)
        self.rd_xzslice_value.toggled.connect(self.txt_xzslice_center_step.setEnabled)
        self.rd_xzslice_range.toggled.connect(self.txt_xzslice_center_to.setDisabled)
        self.rd_xzslice_range.toggled.connect(self.txt_xzslice_center_step.setDisabled)
        self.rd_yzslice_value.toggled.connect(self.txt_xzslice_center_to.setEnabled)
        self.rd_yzslice_value.toggled.connect(self.txt_yzslice_center_step.setEnabled)
        self.rd_yzslice_range.toggled.connect(self.txt_yzslice_center_to.setDisabled)
        self.rd_yzslice_range.toggled.connect(self.txt_yzslice_center_step.setDisabled)

        self.openButton.setDefault(False)
        self.tabWidget_Slice.setCurrentIndex(0)


        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"M2Plot+", None))
        self.actionECM.setText(QCoreApplication.translate("MainWindow", u"ECM", None))
        self.actionTest.setText(QCoreApplication.translate("MainWindow", u"Test", None))
        self.actionShow.setText(QCoreApplication.translate("MainWindow", u"Show", None))
#if QT_CONFIG(shortcut)
        self.actionShow.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+S", None))
#endif // QT_CONFIG(shortcut)
        self.actionECA.setText(QCoreApplication.translate("MainWindow", u"ECA", None))
        self.actionSlice.setText(QCoreApplication.translate("MainWindow", u"Slice", None))
        self.actionRectangle.setText(QCoreApplication.translate("MainWindow", u"Rectangle", None))
        self.actionRectangle.setProperty("regName", QCoreApplication.translate("MainWindow", u"Rectangle", None))
        self.actionCircle.setText(QCoreApplication.translate("MainWindow", u"Circle", None))
        self.actionCircle.setProperty("regName", QCoreApplication.translate("MainWindow", u"Circle", None))
        self.actionConfirm_region.setText(QCoreApplication.translate("MainWindow", u"Confirm region", None))
        self.actionAuto_confirm.setText(QCoreApplication.translate("MainWindow", u"Auto confirm", None))
        self.actionECA_mdb.setText(QCoreApplication.translate("MainWindow", u"ECA Manyo Data", None))
        self.actionECM_mdb.setText(QCoreApplication.translate("MainWindow", u"ECM Manyo Data", None))
        self.actionOpen.setText(QCoreApplication.translate("MainWindow", u"Open data", None))
        self.actionOpen_data.setText(QCoreApplication.translate("MainWindow", u"Open", None))
#if QT_CONFIG(shortcut)
        self.actionOpen_data.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+O", None))
#endif // QT_CONFIG(shortcut)
        self.actionAverage.setText(QCoreApplication.translate("MainWindow", u"Average", None))
        self.actionY_axis_2D.setText(QCoreApplication.translate("MainWindow", u"Y axis 2D", None))
        self.actionX_axis_2D.setText(QCoreApplication.translate("MainWindow", u"X axis 2D", None))
        self.actionPoint.setText(QCoreApplication.translate("MainWindow", u"Point", None))
        self.actionPoint.setProperty("regName", QCoreApplication.translate("MainWindow", u"Point", None))
        self.actionExit.setText(QCoreApplication.translate("MainWindow", u"Exit", None))
#if QT_CONFIG(shortcut)
        self.actionExit.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+X", None))
#endif // QT_CONFIG(shortcut)
        self.actionAbout.setText(QCoreApplication.translate("MainWindow", u"About M2PlotPlus", None))
        self.actionChangeLogLevel.setText(QCoreApplication.translate("MainWindow", u"Change the log level", None))
        self.actionSave_as_Text.setText(QCoreApplication.translate("MainWindow", u"Save as Text...", None))
        self.SumRangePanel.setTitle(QCoreApplication.translate("MainWindow", u"Summation range", None))
        self.label_5.setText(QCoreApplication.translate("MainWindow", u"Range", None))
        self.label_4.setText(QCoreApplication.translate("MainWindow", u"-", None))
        self.label_6.setText(QCoreApplication.translate("MainWindow", u"Key", None))
        self.label_9.setText(QCoreApplication.translate("MainWindow", u"Label", None))
        self.label.setText(QCoreApplication.translate("MainWindow", u"X axis", None))
        self.label_2.setText(QCoreApplication.translate("MainWindow", u"Y axis", None))
        self.label_3.setText(QCoreApplication.translate("MainWindow", u"Intensity", None))
        self.label_8.setText(QCoreApplication.translate("MainWindow", u"Key", None))
        self.label_10.setText(QCoreApplication.translate("MainWindow", u"Unit", None))
        self.showButton.setText(QCoreApplication.translate("MainWindow", u"Show", None))
        self.openButton.setText(QCoreApplication.translate("MainWindow", u"Open", None))
        self.groupBox_int.setTitle(QCoreApplication.translate("MainWindow", u"Inteinsity", None))
        self.chk_int_log.setText(QCoreApplication.translate("MainWindow", u"Log scale", None))
        self.chk_smooth.setText(QCoreApplication.translate("MainWindow", u"Smooth", None))
        self.label_smooth_win.setText(QCoreApplication.translate("MainWindow", u"window", None))
        self.txt_smooth_win.setText(QCoreApplication.translate("MainWindow", u"1", None))
        self.label_smooth_tim.setText(QCoreApplication.translate("MainWindow", u"times", None))
        self.txt_smooth_tim.setText(QCoreApplication.translate("MainWindow", u"1", None))
        self.chk_int_auto_range.setText(QCoreApplication.translate("MainWindow", u"Auto Scale", None))
        self.label_int_range.setText(QCoreApplication.translate("MainWindow", u"Range", None))
        self.label_int_range_h.setText(QCoreApplication.translate("MainWindow", u"-", None))
        self.groupBox_xscale.setTitle(QCoreApplication.translate("MainWindow", u"X Scale", None))
        self.chk_xscale_auto_range.setText(QCoreApplication.translate("MainWindow", u"Auto Scale", None))
        self.label_xscale_range.setText(QCoreApplication.translate("MainWindow", u"Range", None))
        self.label_xscale_h.setText(QCoreApplication.translate("MainWindow", u"-", None))
        self.chk_xscale_log.setText(QCoreApplication.translate("MainWindow", u"Log Scale", None))
        self.chk_xscale_inv.setText(QCoreApplication.translate("MainWindow", u"Inversion", None))
        self.groupBox_yscale.setTitle(QCoreApplication.translate("MainWindow", u"Y Scale", None))
        self.chk_yscale_auto_range.setText(QCoreApplication.translate("MainWindow", u"Auto Scale", None))
        self.label_yscale_range.setText(QCoreApplication.translate("MainWindow", u"Range", None))
        self.label_yscale_h.setText(QCoreApplication.translate("MainWindow", u"-", None))
        self.chk_yscale_log.setText(QCoreApplication.translate("MainWindow", u"Log Scale", None))
        self.chk_yscale_inv.setText(QCoreApplication.translate("MainWindow", u"Inversion", None))
        self.btIntApply.setText(QCoreApplication.translate("MainWindow", u"Apply", None))
        self.groupBox_slice.setTitle(QCoreApplication.translate("MainWindow", u"Slice", None))
        self.cb_xzslice_bin.setText(QCoreApplication.translate("MainWindow", u"rebin", None))
        self.rd_xzslice_range.setText(QCoreApplication.translate("MainWindow", u"Y range", None))
        self.label_xzslice_h.setText(QCoreApplication.translate("MainWindow", u"-", None))
        self.rd_xzslice_value.setText(QCoreApplication.translate("MainWindow", u"Y value", None))
        self.txt_xzslice_delta.setText(QCoreApplication.translate("MainWindow", u"0.0", None))
        self.txt_xzslice_start.setText("")
        self.label_xzslice_width.setText(QCoreApplication.translate("MainWindow", u"delta", None))
        self.label_xzslice_pm.setText(QCoreApplication.translate("MainWindow", u"+-", None))
        self.label_11.setText(QCoreApplication.translate("MainWindow", u"To:", None))
        self.label_12.setText(QCoreApplication.translate("MainWindow", u"Step:", None))
        self.btXZSlice1d.setText(QCoreApplication.translate("MainWindow", u"1D Plot", None))
        self.btXZSlice2d.setText(QCoreApplication.translate("MainWindow", u"2D Plot", None))
        self.btXZSlice1dclear.setText(QCoreApplication.translate("MainWindow", u"Clear", None))
        self.tabWidget_Slice.setTabText(self.tabWidget_Slice.indexOf(self.tab_xzslice), QCoreApplication.translate("MainWindow", u"Along X axis", None))
        self.rd_yzslice_range.setText(QCoreApplication.translate("MainWindow", u"X range", None))
        self.rd_yzslice_value.setText(QCoreApplication.translate("MainWindow", u"X value", None))
        self.label_yzslice_h.setText(QCoreApplication.translate("MainWindow", u"-", None))
        self.txt_yzslice_start.setText("")
        self.label_xzslice_width_2.setText(QCoreApplication.translate("MainWindow", u"delta", None))
        self.txt_yzslice_delta.setText(QCoreApplication.translate("MainWindow", u"0.0", None))
        self.cb_yzslice_bin.setText(QCoreApplication.translate("MainWindow", u"rebin", None))
        self.label_yzslice_pm.setText(QCoreApplication.translate("MainWindow", u"+-", None))
        self.label_13.setText(QCoreApplication.translate("MainWindow", u"To:", None))
        self.label_14.setText(QCoreApplication.translate("MainWindow", u"Step:", None))
        self.btYZSlice1d.setText(QCoreApplication.translate("MainWindow", u"1D Plot", None))
        self.btYZSlice2d.setText(QCoreApplication.translate("MainWindow", u"2D Plot", None))
        self.btYZSlice1dclear.setText(QCoreApplication.translate("MainWindow", u"Clear", None))
        self.tabWidget_Slice.setTabText(self.tabWidget_Slice.indexOf(self.tab_yzslice), QCoreApplication.translate("MainWindow", u"Along Y axis", None))
        self.label_diagonal_sp.setText(QCoreApplication.translate("MainWindow", u"Start:", None))
        self.label_diagonal_ep.setText(QCoreApplication.translate("MainWindow", u"End:", None))
        self.txt_diagonal_ep_x.setText("")
        self.btDiagonal1d.setText(QCoreApplication.translate("MainWindow", u"1D Plot", None))
        self.btDiagonal2d.setText(QCoreApplication.translate("MainWindow", u"2D Plot", None))
        self.label_diagonal_width.setText(QCoreApplication.translate("MainWindow", u"width:", None))
        self.txt_diagonal_binning.setText("")
        self.label_diagonal_binning.setText(QCoreApplication.translate("MainWindow", u"binning:", None))
        self.tabWidget_Slice.setTabText(self.tabWidget_Slice.indexOf(self.tab_diagonal), QCoreApplication.translate("MainWindow", u"Diagonal", None))
        self.label_7.setText(QCoreApplication.translate("MainWindow", u"Integration :", None))
        self.rb_isAveSlice.setText(QCoreApplication.translate("MainWindow", u"Average", None))
        self.rb_isSumSlice.setText(QCoreApplication.translate("MainWindow", u"Summation", None))
        self.tabWidget_Slice.setTabText(self.tabWidget_Slice.indexOf(self.tab), QCoreApplication.translate("MainWindow", u"Settings", None))
        self.btFindPlotter.setText("")
        self.cb_DetMapMode.setText(QCoreApplication.translate("MainWindow", u"DetectMap", None))
        self.menuFile.setTitle(QCoreApplication.translate("MainWindow", u"File", None))
        self.menuEdit.setTitle(QCoreApplication.translate("MainWindow", u"Edit", None))
        self.menuRegion_type.setTitle(QCoreApplication.translate("MainWindow", u"Region type", None))
        self.menuFunction.setTitle(QCoreApplication.translate("MainWindow", u"Function", None))
        self.menuHelp.setTitle(QCoreApplication.translate("MainWindow", u"Help", None))
    # retranslateUi

try:
    import M2PlotPlus_rc
except:
    import uGao.M2PlotPlus_rc

################################################################################
## Form generated from reading UI file 'dg_save_as_text.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_DlgSaveAsText(object):
    def setupUi(self, DlgSaveAsText):
        if not DlgSaveAsText.objectName():
            DlgSaveAsText.setObjectName(u"DlgSaveAsText")
        DlgSaveAsText.resize(400, 205)
        self.ckIgnoreMask = QCheckBox(DlgSaveAsText)
        self.ckIgnoreMask.setObjectName(u"ckIgnoreMask")
        self.ckIgnoreMask.setGeometry(QRect(30, 10, 201, 22))
        self.label = QLabel(DlgSaveAsText)
        self.label.setObjectName(u"label")
        self.label.setGeometry(QRect(30, 40, 181, 17))
        self.chMaskValue = QComboBox(DlgSaveAsText)
        self.chMaskValue.addItem("")
        self.chMaskValue.addItem("")
        self.chMaskValue.addItem("")
        self.chMaskValue.addItem("")
        self.chMaskValue.setObjectName(u"chMaskValue")
        self.chMaskValue.setGeometry(QRect(70, 70, 151, 27))
        self.txMaskValue = QLineEdit(DlgSaveAsText)
        self.txMaskValue.setObjectName(u"txMaskValue")
        self.txMaskValue.setGeometry(QRect(240, 70, 113, 27))
        self.txQbin = QLineEdit(DlgSaveAsText)
        self.txQbin.setObjectName(u"txQbin")
        self.txQbin.setEnabled(False)
        self.txQbin.setGeometry(QRect(240, 110, 113, 27))
        self.stQbin = QLabel(DlgSaveAsText)
        self.stQbin.setObjectName(u"stQbin")
        self.stQbin.setGeometry(QRect(160, 110, 81, 17))
        self.line = QFrame(DlgSaveAsText)
        self.line.setObjectName(u"line")
        self.line.setGeometry(QRect(20, 150, 361, 20))
        self.line.setFrameShape(QFrame.HLine)
        self.line.setFrameShadow(QFrame.Sunken)
        self.btSave = QPushButton(DlgSaveAsText)
        self.btSave.setObjectName(u"btSave")
        self.btSave.setGeometry(QRect(50, 170, 99, 27))
        self.btCancel = QPushButton(DlgSaveAsText)
        self.btCancel.setObjectName(u"btCancel")
        self.btCancel.setGeometry(QRect(260, 170, 99, 27))

        self.retranslateUi(DlgSaveAsText)

        QMetaObject.connectSlotsByName(DlgSaveAsText)
    # setupUi

    def retranslateUi(self, DlgSaveAsText):
        DlgSaveAsText.setWindowTitle(QCoreApplication.translate("DlgSaveAsText", u"Dialog", None))
        self.ckIgnoreMask.setText(QCoreApplication.translate("DlgSaveAsText", u"Ignore Masked Points", None))
        self.label.setText(QCoreApplication.translate("DlgSaveAsText", u"Replace Mask Value with", None))
        self.chMaskValue.setItemText(0, QCoreApplication.translate("DlgSaveAsText", u"Value in right box", None))
        self.chMaskValue.setItemText(1, QCoreApplication.translate("DlgSaveAsText", u"0", None))
        self.chMaskValue.setItemText(2, QCoreApplication.translate("DlgSaveAsText", u"-1", None))
        self.chMaskValue.setItemText(3, QCoreApplication.translate("DlgSaveAsText", u"Original Value", None))

        self.stQbin.setText(QCoreApplication.translate("DlgSaveAsText", u"Q binning", None))
        self.btSave.setText(QCoreApplication.translate("DlgSaveAsText", u"Save", None))
        self.btCancel.setText(QCoreApplication.translate("DlgSaveAsText", u"Cancel", None))
    # retranslateUi




# -*- coding: utf-8 -*-

import sys
import string
import math

import Manyo.core
import ModuleTest as ModTest

ec0 = ModTest.ec0

ne1 = Manyo.NeXusFileIO()
ne1.Write( ec0, "test.nx", "suzuki", 0 )
del ne1


ne2 = Manyo.NeXusFileIO()
e2 = ne2.ReadElementContainer( "test.nx" )
del ne2

#module.PrintElementContainer( e2 )
